# Smashtheque API wrapper

## Installing

**Python 3.5.3 or higher is required**

To install the library, you can just run the following command:

# Linux/macOS
python3 -m pip install -U smashtheque

# Windows
py -3 -m pip install -U smashtheque
